@@ -262,13 +262,13 @@ def graph_plotter(plot_information, values_list, x_limits=("x_min", "x_max"),
                 title_text = "Latitude v Longitude for " + str(flight_dates_list[data_set])
             # Plots map with data
             backplt_map(lat, long, z_var=z_var, z_var_unit=z_var_unit, z_var_data=z_var_data,
-                        z_var_time_data=z_var_time_data, z_var_gps_time_data=z_var_gps_time_data, text_title=title_text,
+                        z_var_time_data=z_var_time_data, time_data=z_var_gps_time_data, text_title=title_text,
                         z_var_limits=map_info_limits)
             plt.show()
             # Plots a second map only if one flight is being analysed
             if single_flight is True:
                 backplt_map(lat, long, z_var=z_var, z_var_unit=z_var_unit, z_var_data=z_var_data,
-                            z_var_time_data=z_var_time_data, z_var_gps_time_data=z_var_gps_time_data,
+                            z_var_time_data=z_var_time_data, time_data=z_var_gps_time_data,
                             scale_factor=float(1 / scale), text_title=title_text, z_var_limits=map_info_limits)
             plt.show()
         return
@@ -390,10 +390,10 @@ def graph_plotter(plot_information, values_list, x_limits=("x_min", "x_max"),
     # Removes new line at end
     plt.title(final_title[:-1], y=1.05)
     # Checks to see if plot limits have been set for the x values
-    if isinstance(x_limits[0], int) and isinstance(x_limits[1], int):
+    if isinstance(x_limits[0], (float, int)) and isinstance(x_limits[1], (float, int)):
         plt.xlim(x_limits)
     # Checks to see if plot limits have been set for the y values
-    if isinstance(y_limits[0], int) and isinstance(y_limits[1], int):
+    if isinstance(y_limits[0], (float, int)) and isinstance(y_limits[1], (float, int)):
         plt.ylim(y_limits)
 
     axes_limits_center_y = (plt.gca().get_ylim()[0] + plt.gca().get_ylim()[1]) / 2
@@ -691,6 +691,10 @@ def multiaxis_graph_plotter(plot_information_left, plot_information_right,
         # Plots the title.
         title = text
 
+    if plot_info != 0:
+        # Assigns a name to be used in the title in case there is no right data.
+        x_variable_name = xy_pairs[0][0][0]
+
     # Records plot info for the left axis
     plot_info_left = plot_info
     # Renames data to make it compatible with older code.
@@ -752,10 +756,10 @@ def multiaxis_graph_plotter(plot_information_left, plot_information_right,
         for pair in xy_pairs:
             # plots x against y values.
             if single_flight is True:
-                line = axis_1.plot(pair[0][2], pair[1][2], label=pair[1][0],
+                line = axis_2.plot(pair[0][2], pair[1][2], label=pair[1][0],
                                    color="C" + str(line_count))
             else:
-                line = axis_1.plot(pair[0][2], pair[1][2], label=(str(pair[1][0]) + " " + str(pair[2])),
+                line = axis_2.plot(pair[0][2], pair[1][2], label=(str(pair[1][0]) + " " + str(pair[2])),
                                    color="C" + str(line_count))
             # Increments line count
             line_count += 1
@@ -811,19 +815,18 @@ def multiaxis_graph_plotter(plot_information_left, plot_information_right,
         plt.close()
         print('No data present or data entered incorrectly.')
         return
+
     if plot_info != 0 and plot_info_left != 0:
         # Plots the title.
         full_title = title + " and " + text
-
-    elif plot_info == 0:
+    elif plot_info == 0 and plot_info_left != 0:
         # Plots the title.
-        full_title = title
+        full_title = title + " v " + x_variable_name
         # Hides right axis if data is missing.
         axis_2.set_yticks([])
     else:
         # Creates a title.
-        full_title = text + " v " + \
-                     xy_pairs[0][0][0]
+        full_title = text
         # Hides left axis if data is missing.
         axis_1.set_yticks([])
         print('Left axis data missing or entered incorrectly.')
@@ -858,15 +861,15 @@ def multiaxis_graph_plotter(plot_information_left, plot_information_right,
         print('Right axis data missing or entered incorrectly.')
 
     # Checks to see if plot limits have been set for the x values
-    if isinstance(x_limits[0], int) and isinstance(x_limits[1], int):
+    if isinstance(x_limits[0], (float, int)) and isinstance(x_limits[1], (float, int)):
         axis_1.set_xlim(x_limits)
     # Checks to see if plot limits have been set for the y values on the left
     # axis.
-    if isinstance(y_limits_left[0], int) and isinstance(y_limits_left[1], int):
+    if isinstance(y_limits_left[0], (float, int)) and isinstance(y_limits_left[1], (float, int)):
         axis_1.set_ylim(y_limits_left)
         # Checks to see if plot limits have been set for the y values on the
         # right axis.
-    if isinstance(y_limits_right[0], int) and isinstance(y_limits_right[1], int):
+    if isinstance(y_limits_right[0], (float, int)) and isinstance(y_limits_right[1], (float, int)):
         axis_2.set_ylim(y_limits_right)
 
     axes_limits_center_y = (plt.gca().get_ylim()[0] + plt.gca().get_ylim()[1]) / 2
@@ -889,18 +892,33 @@ def multiaxis_graph_plotter(plot_information_left, plot_information_right,
     plt.show()
 
 
-def backplt_map(lat, long, z_var=None, z_var_unit=None, z_var_data=None, z_var_time_data=None, z_var_gps_time_data=None,
-                scale_factor=1, text_title=None, z_var_limits=(None, None)):
+def backplt_map(lat, long, time_data, z_var=None, z_var_unit=None, z_var_data=None, z_var_time_data=None,
+                scale_factor=1, text_title=None, z_var_limits=(None, None), disable_prints=False, marker_size=None):
     """
-    Currently this is a support function to graph_plotter() and should not be used on its own.
     This plots a map behind some latitude-longitude data and colours the line according to a third variable (z_var).
 
-    z_var = String for the name of the variable e.g. "Altitude"
-    z_var_unit = String for the units of the variable e.g. "m"
-    z_var_data = List of the data to be plotted e.g. [5, 12, 14]
-    z_var_time_data = List of the time data accompanying z_var_data in seconds e.g. [1, 2, 3]
-    z_var_gps_time_data = List of time data from the gps data set in seconds. This should
-        have the same length as the latitude/longtude data. e.g. [1, 1.5, 2, 2.5, 3]
+    ARGS:
+        lat = A list of latitude data
+        long = A list of longitude data
+        time_data = A list of time data corresponding to the latitude and longitude data in seconds
+
+            lat, long and time_data need to be of the same length.
+
+        z_var = String for the name of the variable e.g. "Altitude"
+        z_var_unit = String for the units of the variable e.g. "m"
+        z_var_data = List of the data to be plotted e.g. [5, 12, 14]
+        z_var_time_data = List of the time data accompanying z_var_data in seconds e.g. [1, 2, 3]
+
+            z_var_data and z_var_time_data should be lists of equal lengths. The z_var_time_data should overlap with the
+                time_data range.
+
+        z_var_limits = Limits to the z_var data in the form [lower_limit, upper_limit].
+                This is not required for plotting z_var.
+
+        disable_prints = If True, warning about no z_var data and map selection advice are not printed.
+        scale_factor = Allows the user to choose how much map is shown. Acts like an inverse zoom from the middle of
+            the plot.
+        marker_size = Size of the markers plotted.
 
     Returns a figure object
     """
@@ -934,7 +952,11 @@ def backplt_map(lat, long, z_var=None, z_var_unit=None, z_var_data=None, z_var_t
     path_data_geo = geo_data_frame
     # Changes the data's coordinate system to epsg 3857 (needed for the
     # maps)
-    path_data_geo = path_data_geo.to_crs(epsg=3857)
+    try:
+        # Catches the unknown error
+        path_data_geo = path_data_geo.to_crs(epsg=3857)
+    except RuntimeError:
+        raise RuntimeError("Unknown error: make sure pyproj is installed correctly.")
 
     # To get the axis labels correctly:
     # Find max and min lat and long.
@@ -957,13 +979,12 @@ def backplt_map(lat, long, z_var=None, z_var_unit=None, z_var_data=None, z_var_t
     # Retrieves data from the dataframe
     geometry_data = [path_data_geo['geometry'].x,
                      path_data_geo['geometry'].y]
-
     # Processes data for the colour scale:
     # Checks that all the necessary data has been entered correctly.
-    z_var_complete = [z_var, z_var_data, z_var_gps_time_data, z_var_unit, z_var_time_data]
+    z_var_complete = [z_var, z_var_data, time_data, z_var_unit, z_var_time_data]
     if all in z_var_complete is None:
         z_var = None
-    elif None in z_var_complete:
+    elif None in z_var_complete and disable_prints is False:
         print("Not enough data entered for plotting a colour scale (z_var). Make sure that z_var, "
               "z_var_unit, z_var_data, z_var_time_data and z_var_gps_time_data have all been completed. If z_var or"
               " z_var_unit are not available, enter an empty string.")
@@ -973,21 +994,25 @@ def backplt_map(lat, long, z_var=None, z_var_unit=None, z_var_data=None, z_var_t
     # Interpolates the data for the colour series over the data's time scale
     if z_var is not None:
         z_var_interp = interp.interp1d(z_var_time_data, z_var_data)
+        geom_x_interp = interp.interp1d(time_data, geometry_data[0])
+        geom_y_interp = interp.interp1d(time_data, geometry_data[1])
 
-        # Creates the data series of same length as the latitude/longitude data:
-        colour_data_uncut = []
-        for point in [p for p in z_var_gps_time_data if min(z_var_time_data) <= p <= max(z_var_time_data)]:
-            colour_data_uncut.append(z_var_interp(point))
+        common_times = []
+        # Finds common times across both data sets
+        for point in time_data:
+            if min(z_var_time_data) <= point <= max(z_var_time_data):
+                common_times.append(point)
 
-        # TODO: THIS NEEDS FIXING IN A WAY THAT WORKS BETTER. NEED TO MATCH THE TIME STAMPS OF THE LOCATION DATA WITH
-        #  THE COLOUR DATA.
-        # Makes sure that the colour data has the same length as the latitude and longitude data
+        # Generates the data across the common_times
         colour_data = []
-        if len(geometry_data[0]) != len(colour_data_uncut):
-            for point in colour_data_uncut[:(len(geometry_data) - 1)]:
-                colour_data.append(point)
-        else:
-            colour_data = colour_data_uncut
+        geom_x = []
+        geom_y = []
+        for point in common_times:
+            geom_x.append(geom_x_interp(point))
+            geom_y.append(geom_y_interp(point))
+            colour_data.append(z_var_interp(point))
+
+        geometry_data = [np.array(geom_x), np.array(geom_y)]
 
         # Creates lists of points of latitude and longitude of colour values above and below the limits specified limits
         # and notes the points
@@ -1026,15 +1051,16 @@ def backplt_map(lat, long, z_var=None, z_var_unit=None, z_var_data=None, z_var_t
 
     # Adds geometry data
     # Highlights user defined outliers
-    for index in range(len(colour_data)):
-        if lower_limit is not None:
-            if colour_data[index] <= lower_limit:
-                low_colour_lat_values.append(geometry_data[0][index])
-                low_colour_long_values.append(geometry_data[1][index])
-        if upper_limit is not None:
-            if colour_data[index] >= upper_limit:
-                high_colour_lat_values.append(geometry_data[0][index])
-                high_colour_long_values.append(geometry_data[1][index])
+    if colour_data is not None:
+        for index in range(len(colour_data)):
+            if lower_limit is not None:
+                if colour_data[index] <= lower_limit:
+                    low_colour_lat_values.append(geometry_data[0][index])
+                    low_colour_long_values.append(geometry_data[1][index])
+            if upper_limit is not None:
+                if colour_data[index] >= upper_limit:
+                    high_colour_lat_values.append(geometry_data[0][index])
+                    high_colour_long_values.append(geometry_data[1][index])
     if scale_factor <= 200:
         # Plots the geometry data using matplotlib
         plt.plot(geometry_data[0], geometry_data[1], 'r', zorder=1,
@@ -1043,7 +1069,7 @@ def backplt_map(lat, long, z_var=None, z_var_unit=None, z_var_data=None, z_var_t
         if colour_data is not None:
             mapplot = plt.scatter(geometry_data[0], geometry_data[1],
                                   c=colour_data, marker='.',
-                                  cmap='gnuplot', zorder=2)
+                                  cmap='gnuplot', zorder=2, s=marker_size)
         else:
             mapplot = plt.scatter(geometry_data[0], geometry_data[1], marker='.', zorder=2)
         # Plots lower and upper limit data if limits are present.
@@ -1114,13 +1140,14 @@ def backplt_map(lat, long, z_var=None, z_var_unit=None, z_var_data=None, z_var_t
 
     try:
         # Tries to plot a Statem terrain map
-        ctx.add_basemap(ax, url=ctx.sources.ST_TERRAIN)
+        ctx.add_basemap(ax, source=ctx.providers.Stamen.Terrain)
     except HTTPError:
         # If the resolution is not good enough, plots an OpenStreetMap
         # instead
-        print('Location does not have high resolution Stamen terrain'
-              ' map data. Defaulting to OpenStreetMap data.')
-        ctx.add_basemap(ax, url=ctx.sources.OSM_A)
+        if disable_prints is False:
+            print('Location does not have high resolution Stamen terrain'
+                  ' map data. Defaulting to OpenStreetMap data.')
+        ctx.add_basemap(ax, source=ctx.providers.OpenStreetMap.Mapnik)
     except ConnectionError:
         # If there is no internet connection present, the map can't be called.
         print('Map unavailable when offline. Try again once an internet '
@@ -1134,7 +1161,7 @@ def backplt_map(lat, long, z_var=None, z_var_unit=None, z_var_data=None, z_var_t
 
     if text_title is not None:
         map_title = text_title
-    elif scale_factor <= 5:
+    elif scale_factor <= 5 and colour_data is not None:
         map_title += " v " + str(z_var)
 
     # Splits title if its width exceeds 60
@@ -1148,7 +1175,7 @@ def backplt_map(lat, long, z_var=None, z_var_unit=None, z_var_data=None, z_var_t
     plt.title(final_title[:-1], y=1.05)
     plt.grid(which='both', axis='both', linewidth=0.2, color="0.1")
     # Adds a colour bar to a plot if the scale is not out of bounds.
-    if scale_factor <= 5:
+    if scale_factor <= 5 and colour_data is not None:
         # Formats location of the colour bar
         divider = make_axes_locatable(ax)
         cax = divider.append_axes("right", size="5%", pad=0.1)
@@ -1161,9 +1188,19 @@ def backplt_map(lat, long, z_var=None, z_var_unit=None, z_var_data=None, z_var_t
 
 
 def take_off_graph(values_list, marker_list=(), take_off_time=None, arm_data=False, alt_sensitivity=0.3,
-                   groundspeed_sensitivity=0.3):
+                   groundspeed_sensitivity=0.3, lower_time_bound=10, upper_time_bound=15):
     """Plots the main variables over the take-off range of the flight on a multi-axis plot.
 
+    ARGS:
+        values_list - output from an AutoFLpy analysis of the flight log
+        marker_list - list, makers to present on the figures for visualisation purposes
+        take_off_time - float, manual time override in case the take-off has not been determined correctly
+        arm_data - bool, show when the aircraft has been armed/disarmed (if applicable)
+        alt_sensitivity - float, sensitivity criterion for determining the altitude change at take-off
+        groundspeed_sensitivity - float, sensitivity criterion for determining the groundspeed change at take-off
+        lower_time_bound - float, time to plot before the take-off point (s)
+        upper_time_bound - float, time to plot after the take-off point (s)
+
     Variables plotted:
     ["altitude", "baro"]
     ["groundspeed", "gps"]
@@ -1174,9 +1211,10 @@ def take_off_graph(values_list, marker_list=(), take_off_time=None, arm_data=Fal
     ["pitch", "ctun"]
     ["desired pitch", "att"]
 
-    ["throttle ch3", "rcin"]
-    ["flap ch5", "rcin"]
-    ["elevator ch2", "rcin"]
+    ["ch1", "rcou"]
+    ["ch2", "rcou"]
+    ["ch3", "rcou"]
+    ["ch4", "rcou"]
     ["current", "bat"]
 
     ["vibex", "vibe"]
@@ -1210,8 +1248,8 @@ def take_off_graph(values_list, marker_list=(), take_off_time=None, arm_data=Fal
             print("Detected ground run start time: ", take_off_time_spd)
 
     # Sets bounds to display on the time axis
-    lower_bound = int(float(take_off_time) - 10)
-    upper_bound = int(float(take_off_time) + 15)
+    lower_bound = int(float(take_off_time) - lower_time_bound)
+    upper_bound = int(float(take_off_time) + upper_time_bound)
 
     # Sets the range for all of the graphs.
     x_limits = [lower_bound, upper_bound]
@@ -1232,8 +1270,8 @@ def take_off_graph(values_list, marker_list=(), take_off_time=None, arm_data=Fal
     graph_plotter([["y", "pitch", "att"], ["y", "desired pitch", "att"], ["x", "time", "att"]], values_list, x_limits,
                   y_limits, marker_list, arm_data=arm_data)
 
-    multiaxis_graph_plotter([["y", "throttle ch3", "rcin"], ["y", "flap ch5", "rcin"], ["y", "elevator ch2", "rcin"],
-                             ["x", "time", "rcin"]], [["y", "current", "bat"], ["x", "time", "bat"]],
+    multiaxis_graph_plotter([["y", "ch1", "rcou"], ["y", "ch2", "rcou"], ["y", "ch3", "rcou"], ["y", "ch4", "rcou"],
+                             ["x", "time", "rcou"]], [["y", "current", "bat"], ["x", "time", "bat"]],
                             values_list, x_limits, y_limits_left, y_limits_right, marker_list,
                             legend_location, arm_data=arm_data)
 
